@@ -17,7 +17,7 @@ import os, datetime
 import hashlib
 from collections import deque
 
-VERSION = "1.2.1"
+VERSION = "1.2.2"
 
 ###############################################################
 class idict(object):
@@ -485,19 +485,22 @@ class dagger(object):
     """Return iterator for all stale nodes listed by name (and their dependents). If [] is given, then all stale nodes (and their dependents) will be returned."""
     if names == None: return []
     
-    if names == []: 
-      return iterator(self, [no for no in self.order.list if no.stale])
-    
+    if names == []: # User wants all stale.
+      stalenames = [no.name for no in self.order.list if no.stale]
+    else:
+      stalenames = [name for name in names if self.nodes[name].stale]
+      
     # Need to preserve dag run order to reduce path checking during iterator.next to guarantee mutual independence, so sort queries by their dag search order indices.
-    sort = [(self.order.index(self.nodes[k]), self.nodes[k]) for k in names if self.nodes[k].stale]
+    sort = [(self.order.index(self.nodes[k]), self.nodes[k]) for k in stalenames]
     sort.sort()
+    
     # Get just the node from the (index,node) sorted tuples.
     requests = [idx_no[1] for idx_no in sort]
     allrequests = ldict(requests)
     
     # Also add dependents (all nodes in path to a root node).
     # They are stale if a child node was stale.
-    [ [ [allrequests.append(pno) for pno in path] for path in no.paths] for no in requests ]
+    [ [ [allrequests.append(pno) for pno in path] for path in no.paths] for no in requests if no.paths]
     
     return iterator(self, allrequests)
     
@@ -511,12 +514,6 @@ class dagger(object):
     if not no.paths: return no.paths
     return [[pno.name for pno in path] for path in no.paths]
 
-  def remove(self, name):
-    """
-    Remove file node 'name' from list of stale nodes found by 'run'. Should be used in conjunction with 'next' when processing files (serial or parallel).
-    """
-    pass
-
   def resetnodes(self):
     """Reset all nodes."""
     [n.reset() for n in self.nodes.values()]
